@@ -25,14 +25,6 @@ our @EXPORT = qw( );
 use overload '='  => sub { $_[0]->clone() },
              'fallback' => 1;
 
-sub clone() {
-  my $self = shift;
-  my $class = ref( $self );
-  my $copy = new2( $self );
-  bless $copy, $class;
-  return $copy;
-}
-
 sub new() {
   my $class = shift;
   my $mset;
@@ -65,7 +57,7 @@ sub fetch() {
     $invalid_args = 1;
   }
   if( $invalid_args ) {
-    Carp::carp( "USAGE: \$mset->fetch(\$begin, \$end), \$mset->fetch(\$msetiterator), \$mset->fetch()" );
+    Carp::carp( "USAGE: \$mset->fetch(\$key, \$value)" );
     exit;
   }
 }
@@ -76,12 +68,10 @@ sub convert_to_percent() {
   if( scalar(@_) == 1 ) {
     my $arg = shift;
     my $arg_class = shift;
-    if( !$arg_class ) {
-      return $self->convert_to_percent1($arg);
-    } elsif( $arg_class eq 'Search::Xapian::MSetIterator' ) {
-      return $self->convert_to_percent2($arg);
+    if( $arg_class eq 'Search::Xapian::MSetIterator' ) {
+      $self->convert_to_percent2($key, $value);
     } else {
-      $invalid_args = 1;
+      $self->convert_to_percent{AUTOLOAD}1($key, $value);
     }
   } else {
     $invalid_args = 1;
